// -*- C++ -*-
//=============================================================================
/**
 *  @file VRT_Wrapper.h
 *
 *  $Id: 
 *
 *  @author  mesnier_p@ociweb.com
 */
  //===========================================================================


#ifndef VRT_WRAPPER_H
#define VRT_WRAPPER_H

class ACE_Virtual_Real_Time; 

/**
 * @class ACE_VRT_Wrapper
 *
 * @brief Extention to allow the use of the concept of "virtual real time".
 *
 * This class provides wrappers around system time based functions. The effect
 * is to have the functions wait an additional amount of time if the current 
 * virtual time has not advanced sufficiently. 
 * 
 */
class ACE_VRT_Wrapper
{
 public:
  
  /// Wrapper for cond_timedwait.
  static int cond_timedwait (ACE_cond_t *cv,
                             ACE_mutex_t *m,
                             ACE_Time_Value *timeout);

  /// Wrapper for sleep.
  static int sleep (u_int seconds);

  static int sleep (const ACE_Time_Value &tv);

  /// Wrapper for nanosleep.
  static int nanosleep (const struct timespec *requested,
                        struct timespec *remaining);

  /// Wrapper for select.
  static int select (int width,
                     fd_set *rfds,
                     fd_set *wfds,
                     fd_set *efds,
                     const ACE_Time_Value *tv = 0);

  /// Wrapper for select.
  static int select (int width,
                     fd_set *rfds,
                     fd_set *wfds,
                     fd_set *efds,
                     const ACE_Time_Value &tv);
  
  /// Wrapper for poll.
  static int poll (struct pollfd *pollfds, 
                   u_long len, 
                   const ACE_Time_Value *tv=0);

  /// Wrapper for poll.
  static int poll (struct pollfd *pollfds, 
                   u_long len, 
                   const ACE_Time_Value &timeout);

  /// Wrapper for alarm.
  static u_int alarm (u_int secs);

  /// Wrapper for ualarm.
  static u_int ualarm (u_int usecs, u_int interval);

  static u_int ualarm (const ACE_Time_Value &tv,
                       const ACE_Time_Value &tv_interval);

  /// Wrapper for sigtimedwait.
  static int sigtimedwait (const sigset_t *set,
                           siginfo_t *info,
                           const ACE_Time_Value *timeout);
  
  /// Wrapper for gettimeofday.
  static ACE_Time_Value gettimeofday (void);
  
  /// Wrapper for gettimeofday based on the Wall-Clock time.
  static ACE_Time_Value getrealtimeofday (void);
  
  /// Wrapper for time.
  static time_t time (time_t *);
  
  //We are not wrapping the clock_gettime function. OK??
  //static clock_gettime (...);

 private:
  ///Pointer to the support class
  //  static ACE_Virtual_Real_Time * vrt_;

};

#if defined (__ACE_INLINE__)
#include "ace/VRT_Wrapper.inl"
#endif /* __ACE_INLINE__ */

#endif /* VRT_WRAPPER_H */






